@@ -1,17 +1,9 @@
 # coding=utf-8
-from django import forms
-from django.core.urlresolvers import reverse
 from django.contrib.auth.forms import PasswordResetForm, SetPasswordForm
-from django.contrib.auth.models import Group, Permission
 from django.contrib.auth.tokens import default_token_generator
 from django.contrib.auth.views import password_reset_confirm
-from django.core.exceptions import PermissionDenied
 from django.template.response import TemplateResponse
-from django.utils.decorators import method_decorator
-from django.http import HttpResponseRedirect
-from django.utils.html import escape
 from django.utils.translation import ugettext as _
-from django.views.decorators.debug import sensitive_post_parameters
 
 from xadmin.sites import site
 from xadmin.views.base import BaseAdminPlugin, BaseAdminView, csrf_protect_m
@@ -19,7 +11,7 @@ from xadmin.views.website import LoginView
 
 
 class ResetPasswordSendView(BaseAdminView):
-    
+
     need_site_permission = False
 
     password_reset_form = PasswordResetForm
@@ -75,7 +67,7 @@ site.register_plugin(ResetLinkPlugin, LoginView)
 
 
 class ResetPasswordComfirmView(BaseAdminView):
-    
+
     need_site_permission = False
 
     password_reset_set_form = SetPasswordForm
@@ -101,12 +93,12 @@ class ResetPasswordComfirmView(BaseAdminView):
         return super(ResetPasswordComfirmView, self).get_media() + \
             self.vendor('xadmin.page.form.js', 'xadmin.form.css')
 
-site.register_view(r'^xadmin/password_reset/(?P<uidb36>[0-9A-Za-z]{1,13})-(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$', 
+site.register_view(r'^xadmin/password_reset/(?P<uidb36>[0-9A-Za-z]{1,13})-(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$',
     ResetPasswordComfirmView, name='xadmin_password_reset_confirm')
 
 
 class ResetPasswordCompleteView(BaseAdminView):
-    
+
     need_site_permission = False
 
     password_reset_complete_template = 'xadmin/auth/password_reset/complete.html'
@@ -114,7 +106,7 @@ class ResetPasswordCompleteView(BaseAdminView):
     def get(self, request, *args, **kwargs):
         context = super(ResetPasswordCompleteView, self).get_context()
         context['login_url'] = self.get_admin_url('index')
-        
+
         return TemplateResponse(request, self.password_reset_complete_template, context,
                                 current_app=self.admin_site.name)
 
