@@ -1,6 +1,4 @@
-from functools import partial
-
-from django.contrib.contenttypes.generic import GenericInlineModelAdmin, GenericRelation
+from django.contrib.contenttypes.generic import GenericRelation
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import PermissionDenied
 from django.db import models
@@ -24,6 +22,7 @@ from xadmin.views.base import csrf_protect_m, filter_hook
 from xadmin.views.detail import DetailAdminUtil
 from reversion.models import Revision, Version
 from reversion.revisions import default_revision_manager, RegistrationError
+from functools import partial
 
 
 def _autoregister(admin, model, follow=None):
@@ -39,7 +38,7 @@ def _autoregister(admin, model, follow=None):
             model, follow=follow, format=admin.reversion_format)
 
 
-def _registe_model(admin, model):
+def _register_model(admin, model):
     if not hasattr(admin, 'revision_manager'):
         admin.revision_manager = default_revision_manager
     if not hasattr(admin, 'reversion_format'):
@@ -70,13 +69,13 @@ def _registe_model(admin, model):
         _autoregister(admin, model, inline_fields)
 
 
-def registe_models(admin_site=None):
+def register_models(admin_site=None):
     if admin_site is None:
         admin_site = site
 
     for model, admin in admin_site._registry.items():
         if getattr(admin, 'reversion_enable', False):
-            _registe_model(admin, model)
+            _register_model(admin, model)
 
 
 class ReversionPlugin(BaseAdminPlugin):
