@@ -76,13 +76,13 @@ vendors = {
             'production': ['xadmin/vendor/load-image/load-image.min.js', 'xadmin/vendor/bootstrap-image-gallery/js/bootstrap-image-gallery.js']
         }
     },
-    "select2": {
+    "select": {
         "css": {
-            'dev': 'xadmin/vendor/select2/select2.css',
+            'dev': ['xadmin/vendor/select2/select2.css', 'xadmin/vendor/selectize/selectize.css', 'xadmin/vendor/selectize/selectize.bootstrap3.css'],
         },
         "js": {
-            'dev': 'xadmin/vendor/select2/select2.js',
-            'production': 'xadmin/vendor/select2/select2.min.js',
+            'dev': ['xadmin/vendor/selectize/selectize.js', 'xadmin/vendor/select2/select2.js'],
+            'production': ['xadmin/vendor/selectize/selectize.min.js', 'xadmin/vendor/select2/select2.min.js']
         }
     },
     "multiselect": {
