@@ -1,5 +1,5 @@
 
-from base import BaseAdminPlugin, BaseAdminView, CommAdminView, ModelAdminView, filter_hook, BaseAdminObject
+from base import BaseAdminPlugin, BaseAdminView, CommAdminView, ModelAdminView, filter_hook, csrf_protect_m, BaseAdminObject
 
 from list import ListAdminView
 from edit import CreateAdminView, UpdateAdminView, ModelFormAdminView
@@ -13,7 +13,8 @@ __all__ = (
     'BaseAdminPlugin', 'BaseAdminView', 'CommAdminView', 'ModelAdminView', 'ListAdminView',
     'ModelFormAdminView', 'CreateAdminView', 'UpdateAdminView', 'DeleteAdminView', 'DetailAdminView',
     'Dashboard', 'BaseWidget',
-    'IndexView', 'LoginView', 'LogoutView'
+    'IndexView', 'LoginView', 'LogoutView',
+    'filter_hook', 'csrf_protect_m'
 )
 
 # admin site-wide views
